@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-sqlite
 version: 2.2
-id: persistent-sqlite-2.2-7d764c09b9ae9cfb2780fa9e0282895f
-key: persi_DnCoYp5nUWvBa2FFMl6PPF
+id: persistent-sqlite-2.2-04957afc1b3cdca0c52cbee96984a045
+key: persi_9ncYKGPwgCJ0i8493T9N2b
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,11 +20,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2
-hs-libraries: HSpersistent-sqlite-2.2-DnCoYp5nUWvBa2FFMl6PPF
+hs-libraries: HSpersistent-sqlite-2.2-9ncYKGPwgCJ0i8493T9N2b
 extra-libraries:
     pthread
 depends:
-    aeson-0.11.0.0-3b69ab8a9952fc7c94fde12b431d717b
+    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
@@ -32,7 +32,7 @@ depends:
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    persistent-2.2.4-bd2986a850822d0f7f277144476772ce
+    persistent-2.2.4-72be3212e3a1e06e6072e64a9625ec8e
     resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
